@@ -8,7 +8,8 @@
 ;; Maintainer: Joost Kremers <joostkremers@fastmail.fm>
 ;; URL: https://codeberg.org/joostkremers/visual-fill-column
 ;; Created: 2015
-;; Version: 2.7.0
+;; Package-Version: 2.7.1
+;; Package-Revision: 9c0ecc2af21d
 ;; Package-Requires: ((emacs "25.1"))
 
 ;; This file is NOT part of GNU Emacs.
@@ -179,7 +180,8 @@ conjunction with `visual-line-mode'."
          (visual-fill-column-mode 1)
          (visual-line-mode 1))
         (t
-         (visual-fill-column-mode -1))))
+         (visual-fill-column-mode -1)
+         (visual-line-mode -1))))
 
 (make-obsolete 'visual-line-fill-column-mode
                "add `visual-fill-column-for-vline' to `visual-line-mode-hook' instead."
